import {
  Component,
  ElementRef,
  OnDestroy,
  OnInit,
  ViewChild,
  ViewEncapsulation
} from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import { DataSource } from '@angular/cdk/collections';
import { BehaviorSubject, fromEvent, merge, Observable, Subject, from } from 'rxjs';
import { debounceTime, distinctUntilChanged, map } from 'rxjs/operators';

import { fuseAnimations } from 'src/@fuse/animations';
import { FuseUtils } from 'src/@fuse/utils';

import { takeUntil } from 'rxjs/internal/operators';

import { User } from '../../../../../../shared/user/model/user.model';
import { UserService } from '../../service/user.service';

@Component({
  selector: 'app-user-user-list',
  templateUrl: './user-list.component.html',
  styleUrls: ['./user-list.component.scss'],
  animations: fuseAnimations,
  encapsulation: ViewEncapsulation.None
})
export class UserListComponent implements OnInit, OnDestroy {

  displayedColumns = [
    'id',
    'phone',
    'status',
    'totalPrice',
    'point',
    'level',
    'chargeMoney',
    'exchangeMoney',
    'revenueMoney',
    'numberOfBets',
    'referrals',
    'recommender',
    'couponStatus',
    'registerDate',
    'recentConnectDate',
    'recentConnectIp'
  ];

  total: number;
  userList: User[];

  @ViewChild(MatPaginator, { static: true })
  paginator: MatPaginator;

  @ViewChild('filter', { static: true })
  filter: ElementRef;

  @ViewChild(MatSort, { static: true })
  sort: MatSort;

  // Private
  private _unsubscribeAll: Subject<any>;

  /**
   * Constructor
   */
  constructor(
    private userService: UserService
  ) {

    // Set the private defaults
    this._unsubscribeAll = new Subject();
  }

  // -----------------------------------------------------------------------------------------------------
  // @ Lifecycle hooks
  // -----------------------------------------------------------------------------------------------------

  /**
   * On init
   */
  ngOnInit(): void {
    this.fetchUserList();
  }

  /**
   * On destroy
   */
  ngOnDestroy(): void {
    // Unsubscribe from all subscriptions
    this._unsubscribeAll.next();
    this._unsubscribeAll.complete();
  }

  fetchUserList() {
    this.userService.getAllUsers().pipe(
      map((userList: User[]) => {

        if (userList && 0 < userList.length) {
          console.log(userList);
        }
      })
    ).subscribe();
  }
}
